@@ -117,7 +117,7 @@ def main():
                         'if not provided, default to same value of $orgprefix.'+ \
                         'Ignored when use "--useec2role" option.')
     parser.add_argument('-mfa','--mfaserial', help='Mfa serial arn used to access target account.')
-    parser.add_argument('-ir','--useec2role', dest='useec2role', action='store_false', help='Use EC2 Instance Role credential instead of source profile.')
+    parser.add_argument('-ir','--useec2role', dest='useec2role', action='store_true', help='Use EC2 Instance Role credential instead of source profile.')
     parser.add_argument('-r','--rolename', help='Role name used to access target account. Default to "OrganizationAccountAccessRole"')
     parser.add_argument('-nc','--ignoreconfigprofile', dest='createawsconfigprofile', action='store_true', help='Create steampipe connection config only, NO ~/.aws/config profiles.')
     parser.set_defaults(useec2role=False)
@@ -143,7 +143,7 @@ def main():
         rolename='OrganizationAccountAccessRole'
 
     createawsconfigprofile=args.createawsconfigprofile
-    useec2rol=args.useec2role
+    useec2role=args.useec2role
     cf = configparser.ConfigParser()
 
     #~/.steampipe/config/<connection file>
@@ -189,9 +189,11 @@ def main():
         shutil.copyfile(awscredpath,awscredpath.replace('credentials','credentials.bak'))
     #读取aws credentials配置文件
     cf.read(awscredpath)
-    if orgprefix+'_base' not in cf.sections():
-        cf.add_section(orgprefix+'_base')
-    cf.set(orgprefix+'_base','credential_process','aws-vault exec -j '+sourceprofile+' --region='+session.region_name)
+    #不使用EC2 Role的情况下生成aws-vault基础credential
+    if not useec2role:
+        if orgprefix+'_base' not in cf.sections():
+            cf.add_section(orgprefix+'_base')
+        cf.set(orgprefix+'_base','credential_process','aws-vault exec -j '+sourceprofile+' --region='+session.region_name)
 
     #生成aws credentials配置文件条目
     for accountel in accountlist:
